Module: WeekOfMonth::Constant
Constant Summary collapse
- WEEK_OF_MONTH_IN_ENG =
hash containing english words from one to seven
{ 1 => 'First', 2 => 'Second', 3 => 'Third', 4 => 'Fourth', 5 => 'Fifth', 6 => 'Sixth', 7 => 'Seventh'}
- WEEK_OF_MONTH_IN_FR =
hash containing french words from one to seven
{ 1 => 'Premier', 2 => 'Deuxième', 3 => 'Troisième', 4 => 'Quatrième', 5 => 'Cinquième', 6 => 'Sixième', 7 => 'Septième'}
- WEEK_OF_MONTH_IN_GER =
hash containing german words from one to seven
{ 1 => 'First', 2 => 'Second', 3 => 'Dritten', 4 => 'Vierte', 5 => 'Fünfte', 6 => 'Sechste', 7 => 'siebte'}
- WEEK_OF_MONTH_IN_JAP =
hash containing japanese words from one to seven
{ 1 => '最初', 2 => '秒', 3 => 'サード', 4 => '第4回', 5 => '第五', 6=> 'シックス', 7 => '第7' }
- MONTH_WITH_DAY =
hash containing month name with days in that month(in non leap year)
{ :january => 31, :february => 28, :march => 31, :april => 30, :may => 31, :june => 30, :july => 31, :august => 31, :september => 30, :october => 31, :november => 30, :december => 31 }
- MONTH_WITH_SEQUENCE =
hash containing month names with their sequence
{ :january => 1, :february => 2, :march => 3, :april => 4, :may => 5, :june => 6, :july => 7, :august => 8, :september => 9, :october => 10, :november => 11, :december => 12 }
- DAYS_IN_SEQUENCE =
array of ordered days names starting from sunday and ending with saturday.
%w(Sunday Monday Tuesday Wednesday Thursday Friday Saturday)
- WEEKS_IN_SEQUENCE =
array of ordered days names starting from sunday and ending with saturday.
%w(Last First Second Third Fourth Fifth)